@@ -43,7 +43,8 @@ class stringDataGiws(dataGiws):
 	nativeType="char *"
 	callMethod="CallObjectMethod"
 	callStaticMethod="CallStaticObjectMethod"
-	
+	temporaryVariableName="myStringBuffer"
+
 	def getTypeSignature(self):
 		return "Ljava/lang/String;"
 
@@ -65,22 +66,22 @@ class stringDataGiws(dataGiws):
 		else:
 			return "char *"
 
-	def specificPreProcessing(self, parameter):
+	def specificPreProcessing(self, parameter, detachThread):
 		""" Overrides the preprocessing of the array """
 		name=parameter.getName()
 		# Management of the error when not enought memory to create the string
 		if configGiws().getThrowsException():
-			errorMgntMem="""throw %s::JniBadAllocException(curEnv);"""%(configGiws().getExceptionFileName())
+			errorMgntMem="""%sthrow %s::JniBadAllocException(curEnv);"""%(detachThread,configGiws().getExceptionFileName())
 		else:
-			errorMgntMem="""std::cerr << "Could not allocate Java string array, memory full." << std::endl;
-			exit(EXIT_FAILURE);"""
+			errorMgntMem="""std::cerr << "Could not allocate Java string array, memory full." << std::endl;%s
+			exit(EXIT_FAILURE);"""%(detachThread)
 
 		# Management of the error when not enought memory to create the string
 		if configGiws().getThrowsException():
-			errorMgntMemBis="""throw %s::JniBadAllocException(curEnv);"""%(configGiws().getExceptionFileName())
+			errorMgntMemBis="""%sthrow %s::JniBadAllocException(curEnv);"""%(detachThread,configGiws().getExceptionFileName())
 		else:
-			errorMgntMemBis="""std::cerr << "Could not convert C string to Java UTF string, memory full." << std::endl;
-			exit(EXIT_FAILURE);"""
+			errorMgntMemBis="""std::cerr << "Could not convert C string to Java UTF string, memory full." << std::endl;%s
+			exit(EXIT_FAILURE);"""%(detachThread)
 
 		if self.isArray():
 			if self.getDimensionArray() == 1:
@@ -145,7 +146,7 @@ class stringDataGiws(dataGiws):
 			jstring %s = curEnv->NewStringUTF( %s );
 			"""%(name+"_",name)
 	
-	def specificPostProcessing(self):
+	def specificPostProcessing(self, detachThread):
 		""" Called when we are returning a string or an array of string """
 		# We are doing an exception check here JUST in this case because
 		# in methodGiws::__createMethodBody we usually do it at the end
@@ -154,7 +155,7 @@ class stringDataGiws(dataGiws):
 		# methods which override the "exception engine" which drive the JNI
 		# engine crazy.
 
-		str=JNIFrameWork().getExceptionCheckProfile()
+		str=JNIFrameWork().getExceptionCheckProfile(detachThread)
 
 		if self.isArray():
 			strCommon=""
@@ -167,6 +168,7 @@ class stringDataGiws(dataGiws):
 			strCommon+="""
 			%s lenRow = curEnv->GetArrayLength(res);
 			"""%(strDeclaration)
+                        self.temporaryVariableName="arrayOfString"
 			if self.getDimensionArray() == 1:
 				str+=strCommon+"""
 				char **arrayOfString;
@@ -211,11 +213,11 @@ class stringDataGiws(dataGiws):
 			return str+"""
 
 			const char *tempString = curEnv->GetStringUTFChars(res, 0);
-			char * myStringBuffer = new char[strlen(tempString) + 1];
-			strcpy(myStringBuffer, tempString);
+			char * %s = new char[strlen(tempString) + 1];
+			strcpy(%s, tempString);
 			curEnv->ReleaseStringUTFChars(res, tempString);
 			curEnv->DeleteLocalRef(res);
-			"""
+			"""%(self.temporaryVariableName, self.temporaryVariableName)
 
 	def getReturnSyntax(self):
 		if self.isArray():
@@ -225,6 +227,6 @@ class stringDataGiws(dataGiws):
 			"""
 		else:
 			return """
-			return myStringBuffer;
-			"""
+			return %s;
+			"""%(self.temporaryVariableName)
 	
